

===============
OpenCMISS-Argon
===============

This package has been renamed. Use :code:`pip install cmlibs.argon` instead.
New package: https://pypi.org/project/cmlibs.argon/

See `OpenCMISS2CMLibs rename tool <https://pypi.org/project/opencmiss2cmlibs/>`_ for help with renaming your own code.
